get_fhir_type

Function get_fhir_type 

pub fn get_fhir_type(value: &dyn MetaValue) -> Option<&'static str>
Helper function to get the FHIR type from a MetaValue Internally on types we generate hashmap of rust type name to FHIR type, so we can use that to get the FHIR type for a given MetaValue.